@@ -5,6 +5,7 @@ import os
 import platform
 import itertools
 import distutils.errors
+
 from setuptools.extern.six.moves import filterfalse
 
 if platform.system() == 'Windows':
@@ -448,10 +449,14 @@ class RegistryInfo:
         for hkey in self.HKEYS:
             try:
                 bkey = winreg.OpenKey(hkey, key, 0, winreg.KEY_READ)
+            except OSError:
+                continue
             except IOError:
                 continue
             try:
                 return winreg.QueryValueEx(bkey, name)[0]
+            except OSError:
+                pass
             except IOError:
                 pass
 
@@ -908,7 +913,7 @@ class EnvironmentInfo:
                 os.path.join(self.si.WindowsSdkDir, 'UnionMetadata'),
                 os.path.join(
                     ref,
-                    'Windows.Foundation.UniversalApiContract'
+                    'Windows.Foundation.UniversalApiContract',
                     '1.0.0.0',
                 ),
                 os.path.join(
@@ -918,7 +923,7 @@ class EnvironmentInfo:
                 ),
                 os.path.join(
                     ref,
-                    'Windows.Networking.Connectivity.WwanContract'
+                    'Windows.Networking.Connectivity.WwanContract',
                     '1.0.0.0',
                 ),
                 os.path.join(
